@@ -319,6 +319,46 @@ def test_text_tspan_anchor_end(assert_pixels):
     ''')
 
 
+@assert_no_logs
+def test_text_anchor_middle_tspan(assert_pixels):
+    assert_pixels('''
+        _______BBBBBB_______
+        _______BBBBBB_______
+    ''', '''
+      <style>
+        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
+        @page { size: 20px 2px }
+        svg { display: block }
+      </style>
+      <svg width="20px" height="2px" xmlns="http://www.w3.org/2000/svg">
+        <text x="10" y="10" font-family="weasyprint" font-size="2" fill="blue"
+              text-anchor="middle">
+          <tspan x="10" y="1.5">ABC</tspan>
+        </text>
+      </svg>
+    ''')
+
+
+@assert_no_logs
+def test_text_anchor_end_tspan(assert_pixels):
+    assert_pixels('''
+        ____________BBBBBB__
+        ____________BBBBBB__
+    ''', '''
+      <style>
+        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
+        @page { size: 20px 2px }
+        svg { display: block }
+      </style>
+      <svg width="20px" height="2px" xmlns="http://www.w3.org/2000/svg">
+        <text x="10" y="10" font-family="weasyprint" font-size="2" fill="blue"
+              text-anchor="end">
+          <tspan x="18" y="1.5">ABC</tspan>
+        </text>
+      </svg>
+    ''')
+
+
 @assert_no_logs
 def test_text_rotate(assert_pixels):
     assert_pixels('''
