@@ -20,7 +20,7 @@ def test_transform_translate(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="0" y="4" width="5" height="5" transform="translate(2, -2)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
@@ -44,7 +44,7 @@ def test_transform_translate_one(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="0" y="2" width="5" height="5" transform="translate(2)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
@@ -68,7 +68,7 @@ def test_transform_translatex(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="0" y="2" width="5" height="5" transform="translateX(2)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
@@ -92,7 +92,7 @@ def test_transform_translatey(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="2" y="0" width="5" height="5" transform="translateY(2)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
@@ -116,7 +116,7 @@ def test_transform_rotate(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="2" y="-7" width="4" height="5" transform="rotate(90)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
@@ -140,7 +140,7 @@ def test_transform_rotate_cx_cy(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="7" y="2" width="4" height="5" transform="rotate(90 7 2)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
@@ -164,7 +164,7 @@ def test_transform_skew(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="2" y="2" width="2" height="2" transform="skew(20 20)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
@@ -188,7 +188,7 @@ def test_transform_skew_one(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="2" y="2" width="2" height="2" transform="skew(20)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
@@ -212,7 +212,7 @@ def test_transform_skewx(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="2" y="2" width="2" height="2" transform="skewX(20)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
@@ -236,7 +236,7 @@ def test_transform_skewy(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="2" y="2" width="2" height="2" transform="skewY(20)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
@@ -260,7 +260,7 @@ def test_transform_scale(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="2" y="2" width="2" height="2" transform="scale(1.5)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
@@ -284,7 +284,7 @@ def test_transform_scale_2(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="2" y="2" width="2" height="2" transform="scale(1.5 1.5)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
@@ -308,7 +308,7 @@ def test_transform_scalex(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="2" y="2" width="2" height="2" transform="scaleX(1.5)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
@@ -332,7 +332,7 @@ def test_transform_scaley(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="2" y="2" width="2" height="2" transform="scaleY(1.5)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
@@ -356,7 +356,7 @@ def test_transform_matrix(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="0" y="0" width="2" height="2"
               transform="matrix(1.5 0 0 1.5 3 3)"
               stroke-width="2" stroke="red" fill="none" />
@@ -381,7 +381,7 @@ def test_transform_multiple(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="0" y="0" width="4" height="5"
               transform="rotate(90) translateY(-7) translateX(2)"
               stroke-width="2" stroke="red" fill="none" />
@@ -406,7 +406,7 @@ def test_transform_unknown(assert_pixels):
         @page { size: 9px }
         svg { display: block }
       </style>
-      <svg width="9px" height="9px" xmlns="https://www.w3.org/2000/svg">
+      <svg width="9px" height="9px" xmlns="http://www.w3.org/2000/svg">
         <rect x="0" y="0" width="4" height="5" transform="unknown(2)"
               stroke-width="2" stroke="red" fill="none" />
       </svg>
