@@ -399,6 +399,58 @@ def test_absolute_split_11(assert_pixels):
     ''')
 
 
+@assert_no_logs
+def test_absolute_split_12(assert_pixels):
+    assert_pixels('''
+        BBBBBB__
+        BBBBBB__
+        ________
+        ________
+        ________
+        ________
+        ________
+        ________
+        BB______
+        BB______
+        BBRR____
+        BBRR____
+        BBRRRR__
+        BBRRRR__
+        BBRRRRRR
+        BBRRRRRR
+    ''', '''
+        <style>
+            @font-face {src: url(weasyprint.otf); font-family: weasyprint}
+            @page {
+                size: 8px;
+            }
+            body {
+                color: blue;
+                font-family: weasyprint;
+                font-size: 2px;
+                line-height: 1;
+            }
+            div {
+                break-inside: avoid;
+            }
+            section {
+                left: 2px;
+                position: absolute;
+                color: red;
+            }
+        </style>
+        aaa
+        <div>
+          a
+          <section>x<br>xx<br>xxx</section>
+          <br>
+          a<br>
+          a<br>
+          a
+        </div>
+    ''')
+
+
 @pytest.mark.xfail
 @assert_no_logs
 def test_absolute_next_page(assert_pixels):
@@ -793,3 +845,54 @@ def test_absolute_image_background(assert_pixels):
         </style>
         <img src="pattern-transparent.svg" />
     ''')
+
+
+@assert_no_logs
+def test_absolute_in_absolute_break(assert_pixels):
+    # Test regression: https://github.com/Kozea/WeasyPrint/issues/2134
+    assert_pixels('''
+        BBBB
+        BBBB
+        BBBB
+        BBBB
+        BBBB
+
+        BBBB
+        BBBB
+        BBBB
+        BBBB
+        BBBB
+
+        BBBB
+        BBBB
+        RRRR
+        RRRR
+        RRRR
+
+        RRRR
+        RRRR
+        ____
+        ____
+        ____
+    ''', '''
+        <style>
+          @page {
+            size: 4px 5px;
+          }
+          body {
+            font-size: 2px;
+            line-height: 1;
+          }
+          div {
+            position: absolute;
+            width: 100%;
+          }
+        </style>
+        <div style="background: blue">
+          <br><br><br><br>
+          <div style="background: red">
+            <br><br>
+          </div>
+        </div>
+        <br><br><br><br><br><br><br>
+    ''')
