@@ -1,15 +1,8 @@
-"""
-    weasyprint.tests.test_draw.test_list
-    ------------------------------------
-
-    Test how lists are drawn.
-
-"""
+"""Test how lists are drawn."""
 
 import pytest
 
 from ..testing_utils import SANS_FONTS, assert_no_logs
-from . import assert_pixels
 
 
 @assert_no_logs
@@ -48,11 +41,11 @@ from . import assert_pixels
         ____________
      ''')
 ))
-def test_list_style_image(position, pixels):
-    assert_pixels(f'list_style_image_{position}', 12, 10, pixels, '''
+def test_list_style_image(assert_pixels, position, pixels):
+    assert_pixels(pixels, '''
       <style>
         @page { size: 12px 10px }
-        body { margin: 0; background: white; font-family: %s }
+        body { margin: 0; font-family: %s }
         ul { margin: 2px 2px 0 7px; list-style: url(pattern.png) %s;
              font-size: 2px }
       </style>
@@ -60,8 +53,8 @@ def test_list_style_image(position, pixels):
 
 
 @assert_no_logs
-def test_list_style_image_none():
-    assert_pixels('list_style_none', 10, 10, '''
+def test_list_style_image_none(assert_pixels):
+    assert_pixels('''
         __________
         __________
         __________
@@ -75,7 +68,7 @@ def test_list_style_image_none():
     ''', '''
       <style>
         @page { size: 10px }
-        body { margin: 0; background: white; font-family: %s }
+        body { margin: 0; font-family: %s }
         ul { margin: 0 0 0 5px; list-style: none; font-size: 2px; }
       </style>
       <ul><li>''' % (SANS_FONTS,))
