@@ -1,12 +1,11 @@
 """Test transformations."""
 
 from ..testing_utils import assert_no_logs
-from . import assert_pixels
 
 
 @assert_no_logs
-def test_2d_transform_1():
-    assert_pixels('image_rotate90', 8, 8, '''
+def test_2d_transform_1(assert_pixels):
+    assert_pixels('''
         ________
         ________
         __BBBr__
@@ -17,15 +16,15 @@ def test_2d_transform_1():
         ________
     ''', '''
       <style>
-        @page { size: 8px; margin: 2px; background: #fff; }
+        @page { size: 8px; margin: 2px; }
         div { transform: rotate(90deg); font-size: 0 }
       </style>
       <div><img src="pattern.png"></div>''')
 
 
 @assert_no_logs
-def test_2d_transform_2():
-    assert_pixels('image_translateX_rotate90', 12, 12, '''
+def test_2d_transform_2(assert_pixels):
+    assert_pixels('''
         ____________
         ____________
         _____BBBr___
@@ -40,7 +39,7 @@ def test_2d_transform_2():
         ____________
     ''', '''
       <style>
-        @page { size: 12px; margin: 2px; background: #fff; }
+        @page { size: 12px; margin: 2px; }
         div { transform: translateX(3px) rotate(90deg);
               font-size: 0; width: 4px }
       </style>
@@ -48,9 +47,9 @@ def test_2d_transform_2():
 
 
 @assert_no_logs
-def test_2d_transform_3():
+def test_2d_transform_3(assert_pixels):
     # A translateX after the rotation is actually a translateY
-    assert_pixels('image_rotate90_translateX', 12, 12, '''
+    assert_pixels('''
         ____________
         ____________
         ____________
@@ -65,7 +64,7 @@ def test_2d_transform_3():
         ____________
     ''', '''
       <style>
-        @page { size: 12px; margin: 2px; background: #fff; }
+        @page { size: 12px; margin: 2px; }
         div { transform: rotate(90deg) translateX(3px);
               font-size: 0; width: 4px }
       </style>
@@ -73,8 +72,8 @@ def test_2d_transform_3():
 
 
 @assert_no_logs
-def test_2d_transform_4():
-    assert_pixels('nested_rotate90_translateX', 12, 12, '''
+def test_2d_transform_4(assert_pixels):
+    assert_pixels('''
         ____________
         ____________
         ____________
@@ -89,7 +88,7 @@ def test_2d_transform_4():
         ____________
     ''', '''
       <style>
-        @page { size: 12px; margin: 2px; background: #fff; }
+        @page { size: 12px; margin: 2px; }
         div { transform: rotate(90deg); font-size: 0; width: 4px }
         img { transform: translateX(3px) }
       </style>
@@ -97,8 +96,8 @@ def test_2d_transform_4():
 
 
 @assert_no_logs
-def test_2d_transform_5():
-    assert_pixels('image_reflection', 8, 8, '''
+def test_2d_transform_5(assert_pixels):
+    assert_pixels('''
         ________
         ________
         __BBBr__
@@ -109,15 +108,15 @@ def test_2d_transform_5():
         ________
     ''', '''
       <style>
-        @page { size: 8px; margin: 2px; background: #fff; }
+        @page { size: 8px; margin: 2px; }
         div { transform: matrix(-1, 0, 0, 1, 0, 0); font-size: 0 }
       </style>
       <div><img src="pattern.png"></div>''')
 
 
 @assert_no_logs
-def test_2d_transform_6():
-    assert_pixels('image_translate', 8, 8, '''
+def test_2d_transform_6(assert_pixels):
+    assert_pixels('''
         ________
         ________
         ________
@@ -128,15 +127,15 @@ def test_2d_transform_6():
         ___BBBB_
     ''', '''
       <style>
-        @page { size: 8px; margin: 2px; background: #fff; }
+        @page { size: 8px; margin: 2px; }
         div { transform: translate(1px, 2px); font-size: 0 }
       </style>
       <div><img src="pattern.png"></div>''')
 
 
 @assert_no_logs
-def test_2d_transform_7():
-    assert_pixels('image_translate_percentage', 8, 8, '''
+def test_2d_transform_7(assert_pixels):
+    assert_pixels('''
         ________
         ________
         ___rBBB_
@@ -147,15 +146,15 @@ def test_2d_transform_7():
         ________
     ''', '''
       <style>
-        @page { size: 8px; margin: 2px; background: #fff; }
+        @page { size: 8px; margin: 2px; }
         div { transform: translate(25%, 0); font-size: 0 }
       </style>
       <div><img src="pattern.png"></div>''')
 
 
 @assert_no_logs
-def test_2d_transform_8():
-    assert_pixels('image_translateX', 8, 8, '''
+def test_2d_transform_8(assert_pixels):
+    assert_pixels('''
         ________
         ________
         _____rBB
@@ -166,7 +165,7 @@ def test_2d_transform_8():
         ________
     ''', '''
       <style>
-        @page { size: 8px; margin: 2px; background: #fff; }
+        @page { size: 8px; margin: 2px; }
         div { transform: translateX(0.25em); font-size: 12px }
         div div { font-size: 0 }
       </style>
@@ -174,8 +173,8 @@ def test_2d_transform_8():
 
 
 @assert_no_logs
-def test_2d_transform_9():
-    assert_pixels('image_translateY', 8, 8, '''
+def test_2d_transform_9(assert_pixels):
+    assert_pixels('''
         ________
         __rBBB__
         __BBBB__
@@ -186,15 +185,15 @@ def test_2d_transform_9():
         ________
     ''', '''
       <style>
-        @page { size: 8px; margin: 2px; background: #fff; }
+        @page { size: 8px; margin: 2px; }
         div { transform: translateY(-1px); font-size: 0 }
       </style>
       <div><img src="pattern.png"></div>''')
 
 
 @assert_no_logs
-def test_2d_transform_10():
-    assert_pixels('image_scale', 10, 10, '''
+def test_2d_transform_10(assert_pixels):
+    assert_pixels('''
         __________
         _rrBBBBBB_
         _rrBBBBBB_
@@ -207,7 +206,7 @@ def test_2d_transform_10():
         __________
     ''', '''
       <style>
-        @page { size: 10px; margin: 2px; background: #fff; }
+        @page { size: 10px; margin: 2px; }
         div { transform: scale(2, 2);
               transform-origin: 1px 1px 1px;
               image-rendering: pixelated;
@@ -217,8 +216,8 @@ def test_2d_transform_10():
 
 
 @assert_no_logs
-def test_2d_transform_11():
-    assert_pixels('image_scale12', 10, 10, '''
+def test_2d_transform_11(assert_pixels):
+    assert_pixels('''
         __________
         __rBBB____
         __rBBB____
@@ -231,7 +230,7 @@ def test_2d_transform_11():
         __________
     ''', '''
       <style>
-        @page { size: 10px; margin: 2px; background: #fff; }
+        @page { size: 10px; margin: 2px; }
         div { transform: scale(1, 2);
               transform-origin: 1px 1px;
               image-rendering: pixelated;
@@ -241,8 +240,8 @@ def test_2d_transform_11():
 
 
 @assert_no_logs
-def test_2d_transform_12():
-    assert_pixels('image_scaleY', 10, 10, '''
+def test_2d_transform_12(assert_pixels):
+    assert_pixels('''
         __________
         __rBBB____
         __rBBB____
@@ -255,7 +254,7 @@ def test_2d_transform_12():
         __________
     ''', '''
       <style>
-        @page { size: 10px; margin: 2px; background: #fff; }
+        @page { size: 10px; margin: 2px; }
         div { transform: scaleY(2);
               transform-origin: 1px 1px 0;
               image-rendering: pixelated;
@@ -265,8 +264,8 @@ def test_2d_transform_12():
 
 
 @assert_no_logs
-def test_2d_transform_13():
-    assert_pixels('image_scaleX', 10, 10, '''
+def test_2d_transform_13(assert_pixels):
+    assert_pixels('''
         __________
         __________
         _rrBBBBBB_
@@ -279,10 +278,32 @@ def test_2d_transform_13():
         __________
     ''', '''
       <style>
-        @page { size: 10px; margin: 2px; background: #fff; }
+        @page { size: 10px; margin: 2px; }
         div { transform: scaleX(2);
               transform-origin: 1px 1px;
               image-rendering: pixelated;
               font-size: 0 }
       </style>
       <div><img src="pattern.png"></div>''')
+
+
+@assert_no_logs
+def test_2d_transform_opacity(assert_pixels):
+    assert_pixels('''
+        __________
+        __________
+        __________
+        _ss_______
+        _ss_______
+        __________
+        __________
+        __________
+        __________
+        __________
+    ''', '''
+      <style>
+        @page { size: 10px; margin: 2px; }
+        div { transform: translate(-1px, 1px); background: red;
+              height: 2px; width: 2px; opacity: 0.5 }
+      </style>
+      <div></div>''')
