@@ -1,20 +1,13 @@
-"""
-    weasyprint.tests.test_draw.test_visibility
-    ------------------------------------------
-
-    Test visibility.
-
-"""
+"""Test visibility."""
 
 from ..testing_utils import assert_no_logs
-from . import assert_pixels
 
 visibility_source = '''
   <style>
     @page { size: 12px 7px }
-    body { background: #fff; font: 1px/1 serif }
+    body { font: 1px/1 serif }
     img { margin: 1px 0 0 1px; }
-    %(extra_css)s
+    %s
   </style>
   <div>
     <img src="pattern.png">
@@ -23,8 +16,8 @@ visibility_source = '''
 
 
 @assert_no_logs
-def test_visibility_1():
-    assert_pixels('visibility_reference', 12, 7, '''
+def test_visibility_1(assert_pixels):
+    assert_pixels('''
         ____________
         _rBBB_rBBB__
         _BBBB_BBBB__
@@ -32,12 +25,12 @@ def test_visibility_1():
         _BBBB_BBBB__
         ____________
         ____________
-    ''', visibility_source % {'extra_css': ''})
+    ''', visibility_source % '')
 
 
 @assert_no_logs
-def test_visibility_2():
-    assert_pixels('visibility_hidden', 12, 7, '''
+def test_visibility_2(assert_pixels):
+    assert_pixels('''
         ____________
         ____________
         ____________
@@ -45,12 +38,12 @@ def test_visibility_2():
         ____________
         ____________
         ____________
-    ''', visibility_source % {'extra_css': 'div { visibility: hidden }'})
+    ''', visibility_source % 'div { visibility: hidden }')
 
 
 @assert_no_logs
-def test_visibility_3():
-    assert_pixels('visibility_mixed', 12, 7, '''
+def test_visibility_3(assert_pixels):
+    assert_pixels('''
         ____________
         ______rBBB__
         ______BBBB__
@@ -58,5 +51,18 @@ def test_visibility_3():
         ______BBBB__
         ____________
         ____________
-    ''', visibility_source % {'extra_css': '''div { visibility: hidden }
-                                 span { visibility: visible } '''})
+    ''', visibility_source % 'div { visibility: hidden } '
+                             'span { visibility: visible }')
+
+
+@assert_no_logs
+def test_visibility_4(assert_pixels):
+    assert_pixels('''
+        ____________
+        _rBBB_rBBB__
+        _BBBB_BBBB__
+        _BBBB_BBBB__
+        _BBBB_BBBB__
+        ____________
+        ____________
+    ''', visibility_source % '@page { visibility: hidden; background: red }')
