@@ -1,11 +1,11 @@
 """Tests for layout of tables."""
 
 import pytest
+
 from weasyprint.formatting_structure import boxes
 from weasyprint.layout.table import collapse_table_borders
 
-from ..testing_utils import (
-    assert_no_logs, capture_logs, parse_all, render_pages)
+from ..testing_utils import assert_no_logs, capture_logs, parse_all, render_pages
 
 
 def _get_grid(html, grid_width, grid_height):
@@ -515,7 +515,7 @@ def test_layout_table_auto_8():
 @assert_no_logs
 def test_layout_table_auto_9():
     page, = render_pages('''
-      <table style="border-spacing: 10px; width: 110px; margin: 5px">
+      <table style="border-spacing: 10px; width: 120px; margin: 5px">
         <tr>
           <td style="width: 60px"></td>
           <td></td>
@@ -1113,8 +1113,8 @@ def test_layout_table_auto_31():
 def test_layout_table_auto_32():
     # Table with a cell larger than the table's width
     page, = render_pages('''
-      <table style="width: 300px; margin: 100px">
-        <td style="width: 400px"></td>
+      <table style="width: 400px; margin: 100px">
+        <td style="width: 500px"></td>
       </table>
     ''')
     html, = page.children
@@ -1298,11 +1298,14 @@ def test_layout_table_auto_41():
 def test_layout_table_auto_42():
     # Cell width as percentage in auto-width table
     page, = render_pages('''
-      <table>
+      <style>
+        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
+      </style>
+      <table style="font-family: weasyprint">
         <tbody>
             <tr>
-              <td style="width: 70px">a a a a a a a a</td>
-              <td style="width: 30%">a a a a a a a a</td>
+              <td style="width: 70px">aaa</td>
+              <td style="width: 25%">aaa</td>
             </tr>
         </tbody>
       </table>
@@ -1314,9 +1317,9 @@ def test_layout_table_auto_42():
     row_group, = table.children
     row, = row_group.children
     td_1, td_2 = row.children
-    assert td_1.width == 70
-    assert td_2.width == 30
-    assert table.width == 100
+    assert td_2.width == 16 * 3  # Percentage column is set to max-width
+    assert td_1.width == (16 * 3) * 3  # Pixel column constraint is ignored
+    assert table.width == (16 * 3) * 4
 
 
 @assert_no_logs
@@ -1554,6 +1557,32 @@ def test_layout_table_auto_50():
     assert td_21.width == 240  # 15 * font_size
 
 
+@assert_no_logs
+def test_layout_table_auto_51():
+    # Test regression:
+    # https://github.com/Kozea/WeasyPrint/issues/2174
+    page, = render_pages('''
+      <style>
+        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
+      </style>
+      <table style="font-family: weasyprint; width: 100px">
+        <tr>
+          <td style="width: 29.9999%">a</td>
+          <td style="width: 70%">a</td>
+        </tr>
+      </table>
+    ''')
+    html, = page.children
+    body, = html.children
+    table_wrapper, = body.children
+    table, = table_wrapper.children
+    row_group, = table.children
+    row_1, = row_group.children
+    td_1, td_2 = row_1.children
+    assert abs(td_1.width - 30) < 0.1
+    assert abs(td_2.width - 70) < 0.1
+
+
 @assert_no_logs
 @pytest.mark.parametrize(
     'body_width, table_width, check_width, positions, widths', (
@@ -1961,7 +1990,7 @@ def test_table_vertical_align(assert_pixels):
           </td>
         </tr>
       </table>
-    ''')  # noqa
+    ''')
 
 
 @assert_no_logs
@@ -2800,6 +2829,100 @@ def test_table_empty_body(rows_expected, thead, tfoot, content):
         assert rows == rows_expected[i]
 
 
+def test_table_group_break_inside_avoid_absolute():
+    # Test regression: https://github.com/Kozea/WeasyPrint/issues/2134
+    html = '''
+      <style>
+        @page { size: 5cm }
+        tbody { break-inside: avoid; line-height: 2cm }
+        div { position: absolute }
+      </style>
+      <table>
+        <tbody><tr><td>a</td></tr></tbody>
+        <tbody><tr>
+          <td><div>a<br>b</div></td>
+          <td>a<br>b</td>
+        </tr></tbody>
+      </table>
+    '''
+    page1, page2 = render_pages(html)
+
+    html, = page1.children
+    body, = html.children
+    table_wrapper, = body.children
+    table, = table_wrapper.children
+    group, = table.children  # Only first group
+
+    html, = page2.children
+    body, = html.children  # No absolute div here
+    table_wrapper, = body.children
+    table, = table_wrapper.children
+    group, = table.children  # Only second group
+
+
+def test_table_row_break_inside_avoid_absolute():
+    # Test regression: https://github.com/Kozea/WeasyPrint/issues/2134
+    html = '''
+      <style>
+        @page { size: 5cm }
+        tr { break-inside: avoid; line-height: 2cm }
+        div { position: absolute }
+      </style>
+      <table>
+        <tr><td>a</td></tr>
+        <tr>
+          <td><div>a<br>b</div></td>
+          <td>a<br>b</td>
+        </tr>
+      </table>
+    '''
+    page1, page2 = render_pages(html)
+
+    html, = page1.children
+    body, = html.children
+    table_wrapper, = body.children
+    table, = table_wrapper.children
+    group, = table.children
+    row, = group.children  # Only first row
+
+    html, = page2.children
+    body, = html.children  # No absolute div here
+    table_wrapper, = body.children
+    table, = table_wrapper.children
+    group, = table.children
+    row, = group.children  # Only second row
+
+
+def test_table_break_inside_avoid_absolute():
+    # Test regression: https://github.com/Kozea/WeasyPrint/issues/2134
+    html = '''
+      <style>
+        @page { size: 5cm }
+        body { line-height: 2cm }
+        table { break-inside: avoid }
+        div { position: absolute }
+      </style>
+      <p>text</p>
+      <table>
+        <tr>
+          <td><div>a<br>b</div></td>
+          <td>a<br>b</td>
+        </tr>
+      </table>
+    '''
+    page1, page2 = render_pages(html)
+
+    html, = page1.children
+    body, = html.children
+    p, = body.children
+    line, = p.children
+    text, = line.children
+    assert text.text == 'text'
+
+    html, = page2.children
+    body, = html.children  # No absolute div here
+
+
 def test_table_break_children_margin():
     # Test regression: https://github.com/Kozea/WeasyPrint/issues/1254
     html = '''
@@ -3009,6 +3132,34 @@ table.key-val tr td:nth-child(1) { min-width: 13em; }
     assert table1_td1.width == table2_td1.width
 
 
+@assert_no_logs
+def test_table_cell_max_width():
+    page, = render_pages('''
+    <style>
+      td {
+        text-overflow: ellipsis;
+        white-space: nowrap;
+        overflow: hidden;
+        max-width: 45px;
+      }
+    </style>
+      <table>
+        <tr>
+          <td>abcdefghijkl</td>
+        </tr>
+      </table>
+    ''')
+    html, = page.children
+    body, = html.children
+    table_wrapper, = body.children
+    table, = table_wrapper.children
+    tbody, = table.children
+    tr, = tbody.children
+    td, = tr.children
+    assert td.max_width == 45
+    assert td.width == 45
+
+
 black = (0, 0, 0, 1)
 red = (1, 0, 0, 1)
 green = (0, 1, 0, 1)  # lime in CSS
