@@ -13,21 +13,27 @@ on other functions in this module.
 """
 
 from collections import namedtuple
+from itertools import groupby
 from logging import DEBUG, WARNING
 
 import cssselect2
 import tinycss2
+import tinycss2.ast
 import tinycss2.nth
 
 from .. import CSS
 from ..logger import LOGGER, PROGRESS_LOGGER
 from ..urls import URLFetchingError, get_url_attribute, url_join
-from . import computed_values, counters, media_queries
-from .properties import INHERITED, INITIAL_NOT_COMPUTED, INITIAL_VALUES
-from .utils import get_url, remove_whitespace
+from . import counters, media_queries
+from .computed_values import COMPUTER_FUNCTIONS
+from .properties import INHERITED, INITIAL_NOT_COMPUTED, INITIAL_VALUES, ZERO_PIXELS
 from .validation import preprocess_declarations
 from .validation.descriptors import preprocess_descriptors
 
+from .utils import (  # isort:skip
+    InvalidValues, Pending, check_var_function, get_url, parse_function,
+    remove_whitespace)
+
 # Reject anything not in here:
 PSEUDO_ELEMENTS = (
     None, 'before', 'after', 'marker', 'first-line', 'first-letter',
@@ -124,13 +130,13 @@ class StyleFor:
                     style['border_collapse'] == 'collapse'):
                 # Padding do not apply
                 for side in ('top', 'bottom', 'left', 'right'):
-                    style[f'padding_{side}'] = computed_values.ZERO_PIXELS
+                    style[f'padding_{side}'] = ZERO_PIXELS
             if (len(style['display']) == 1 and
                     style['display'][0].startswith('table-') and
                     style['display'][0] != 'table-caption'):
                 # Margins do not apply
                 for side in ('top', 'bottom', 'left', 'right'):
-                    style[f'margin_{side}'] = computed_values.ZERO_PIXELS
+                    style[f'margin_{side}'] = ZERO_PIXELS
 
         return style
 
@@ -163,18 +169,6 @@ class StyleFor:
             element, cascaded, parent_style, pseudo_type, root_style, base_url,
             target_collector)
 
-        # The style of marker is deleted when display is different from
-        # list-item.
-        if pseudo_type is None:
-            for pseudo in (None, 'before', 'after'):
-                pseudo_style = cascaded_styles.get((element, pseudo), {})
-                if 'display' in pseudo_style:
-                    if 'list-item' in pseudo_style['display'][0]:
-                        break
-            else:
-                if (element, 'marker') in cascaded_styles:
-                    del cascaded_styles[element, 'marker']
-
     def add_page_declarations(self, page_type):
         for sheet, origin, sheet_specificity in self._sheets:
             for _rule, selector_list, declarations in sheet.page_rules:
@@ -304,7 +298,7 @@ def find_style_attributes(tree, presentational_hints=False, base_url=None):
 
     """
     def check_style_attribute(element, style_attribute):
-        declarations = tinycss2.parse_declaration_list(style_attribute)
+        declarations = tinycss2.parse_blocks_contents(style_attribute)
         return element, declarations, base_url
 
     for element in tree.iter():
@@ -600,6 +594,32 @@ def declaration_precedence(origin, importance):
         return 5
 
 
+def resolve_var(computed, token, parent_style):
+    """Return token with resolved CSS variables."""
+    if not check_var_function(token):
+        return
+
+    if token.lower_name != 'var':
+        arguments = []
+        for i, argument in enumerate(token.arguments):
+            if argument.type == 'function' and argument.lower_name == 'var':
+                arguments.extend(resolve_var(computed, argument, parent_style))
+            else:
+                arguments.append(argument)
+        token = tinycss2.ast.FunctionBlock(
+            token.source_line, token.source_column, token.name, arguments)
+        return resolve_var(computed, token, parent_style) or (token,)
+
+    args = parse_function(token)[1]
+    variable_name = args.pop(0).value.replace('-', '_')  # first arg is name
+    default = args  # next args are default value
+    computed_value = []
+    for value in (computed[variable_name] or default):
+        resolved = resolve_var(computed, value, parent_style)
+        computed_value.extend((value,) if resolved is None else resolved)
+    return computed_value
+
+
 class AnonymousStyle(dict):
     """Computed style used for anonymous boxes."""
     def __init__(self, parent_style):
@@ -667,75 +687,91 @@ class ComputedStyle(dict):
 
     def __missing__(self, key):
         if key == 'float':
-            # Set specified value for position, needed for computed value
+            # Set specified value for position, needed for computed value.
             self['position']
         elif key == 'display':
-            # Set specified value for float, needed for computed value
+            # Set specified value for float, needed for computed value.
             self['float']
 
+        parent_style = self.parent_style
+
         if key in self.cascaded:
-            value = keyword = self.cascaded[key][0]
+            # Property defined in cascaded properties.
+            value = self.cascaded[key][0]
+            pending = isinstance(value, Pending)
         else:
+            # Property not defined in cascaded properties, define as inherited
+            # or initial value.
             if key in INHERITED or key[:2] == '__':
-                keyword = 'inherit'
+                value = 'inherit'
             else:
-                keyword = 'initial'
+                value = 'initial'
+            pending = False
 
-        if keyword == 'inherit' and self.parent_style is None:
+        if value == 'inherit' and parent_style is None:
             # On the root element, 'inherit' from initial values
-            keyword = 'initial'
+            value = 'initial'
 
-        if keyword == 'initial':
-            value = None if key[:2] == '__' else INITIAL_VALUES[key]
+        if pending:
+            # Property with pending values, validate them.
+            solved_tokens = []
+            for token in value.tokens:
+                tokens = resolve_var(self, token, parent_style)
+                if tokens is None:
+                    solved_tokens.append(token)
+                else:
+                    solved_tokens.extend(tokens)
+            original_key = key.replace('_', '-')
+            try:
+                value = value.solve(solved_tokens, original_key)
+            except InvalidValues:
+                if key in INHERITED and parent_style is not None:
+                    # Values in parent_style are already computed.
+                    self[key] = value = parent_style[key]
+                else:
+                    value = INITIAL_VALUES[key]
+                    if key not in INITIAL_NOT_COMPUTED:
+                        # The value is the same as when computed.
+                        self[key] = value
+
+        if value == 'initial':
+            value = [] if key[:2] == '__' else INITIAL_VALUES[key]
             if key not in INITIAL_NOT_COMPUTED:
-                # The value is the same as when computed
+                # The value is the same as when computed.
                 self[key] = value
-        elif keyword == 'inherit':
+        elif value == 'inherit':
             # Values in parent_style are already computed.
-            self[key] = value = self.parent_style[key]
+            self[key] = value = parent_style[key]
 
-        if key[:16] == 'text_decoration_' and self.parent_style:
+        if key[:16] == 'text_decoration_' and parent_style is not None:
+            # Text decorations are not inherited but propagated. See
+            # https://www.w3.org/TR/css-text-decor-3/#line-decoration.
             value = text_decoration(
-                key, value, self.parent_style[key], key in self.cascaded)
+                key, value, parent_style[key], key in self.cascaded)
             if key in self:
                 del self[key]
         elif key == 'page' and value == 'auto':
-            # The page property does not inherit. However, if the page
-            # value on an element is auto, then its used value is the value
-            # specified on its nearest ancestor with a non-auto value. When
-            # specified on the root element, the used value for auto is the
-            # empty string.
-            value = (
-                '' if self.parent_style is None else self.parent_style['page'])
+            # The page property does not inherit. However, if the page value on
+            # an element is auto, then its used value is the value specified on
+            # its nearest ancestor with a non-auto value. When specified on the
+            # root element, the used value for auto is the empty string. See
+            # https://www.w3.org/TR/css-page-3/#using-named-pages.
+            value = '' if parent_style is None else parent_style['page']
             if key in self:
                 del self[key]
         elif key in ('position', 'float', 'display'):
+            # Save specified values to define computed values for these
+            # specific properties. See
+            # https://www.w3.org/TR/CSS21/visuren.html#dis-pos-flo.
             self.specified[key] = value
 
         if key in self:
+            # Value already computed and saved: return.
             return self[key]
 
-        function = computed_values.COMPUTER_FUNCTIONS.get(key)
-        already_computed_value = False
-
-        if value:
-            converted_to_list = False
-
-            if not isinstance(value, list):
-                converted_to_list = True
-                value = [value]
-
-            for i, v in enumerate(value):
-                value[i], already_computed_value = (
-                    computed_values.compute_variable(
-                        v, key, self, self.base_url, self.parent_style))
-
-            if converted_to_list:
-                value, = value
-
-        if function is not None and not already_computed_value:
-            value = function(self, key, value)
-        # else: same as specified
+        if key in COMPUTER_FUNCTIONS:
+            # Value not computed yet: compute.
+            value = COMPUTER_FUNCTIONS[key](self, key, value)
 
         self[key] = value
         return value
@@ -884,33 +920,42 @@ def preprocess_stylesheet(device_media_type, base_url, stylesheet_rules,
             continue
 
         if rule.type == 'qualified-rule':
-            declarations = list(preprocess_declarations(
-                base_url, tinycss2.parse_declaration_list(rule.content)))
-            if declarations:
+            try:
                 logger_level = WARNING
-                try:
-                    selectors = cssselect2.compile_selector_list(rule.prelude)
-                    for selector in selectors:
-                        matcher.add_selector(selector, declarations)
-                        if selector.pseudo_element not in PSEUDO_ELEMENTS:
-                            if selector.pseudo_element.startswith('-'):
-                                logger_level = DEBUG
-                                raise cssselect2.SelectorError(
-                                    'ignored prefixed pseudo-element: '
-                                    f'{selector.pseudo_element}')
-                            else:
-                                raise cssselect2.SelectorError(
-                                    'unknown pseudo-element: '
-                                    f'{selector.pseudo_element}')
+                selectors_declarations = list(
+                    preprocess_declarations(
+                        base_url, tinycss2.parse_blocks_contents(rule.content),
+                        rule.prelude))
+
+                if selectors_declarations:
+                    selectors_declarations = groupby(
+                        selectors_declarations, key=lambda x: x[0])
+                    for selectors, declarations in selectors_declarations:
+                        declarations = [
+                            declaration[1] for declaration in declarations]
+                        for selector in selectors:
+                            matcher.add_selector(selector, declarations)
+                            if selector.pseudo_element not in PSEUDO_ELEMENTS:
+                                prelude = tinycss2.serialize(rule.prelude)
+                                if selector.pseudo_element.startswith('-'):
+                                    logger_level = DEBUG
+                                    raise cssselect2.SelectorError(
+                                        f"'{prelude}', "
+                                        'ignored prefixed pseudo-element: '
+                                        f'{selector.pseudo_element}')
+                                else:
+                                    raise cssselect2.SelectorError(
+                                        f"'{prelude}', "
+                                        'unknown pseudo-element: '
+                                        f'{selector.pseudo_element}')
+                        ignore_imports = True
+                else:
                     ignore_imports = True
-                except cssselect2.SelectorError as exc:
-                    LOGGER.log(
-                        logger_level,
-                        "Invalid or unsupported selector '%s', %s",
-                        tinycss2.serialize(rule.prelude), exc)
-                    continue
-            else:
-                ignore_imports = True
+            except cssselect2.SelectorError as exc:
+                LOGGER.log(
+                    logger_level,
+                    "Invalid or unsupported selector, %s", exc)
+                continue
 
         elif rule.type == 'at-rule' and rule.lower_at_keyword == 'import':
             if ignore_imports:
@@ -991,7 +1036,7 @@ def preprocess_stylesheet(device_media_type, base_url, stylesheet_rules,
             for page_type in data:
                 specificity = page_type.pop('specificity')
                 page_type = PageType(**page_type)
-                content = tinycss2.parse_declaration_list(rule.content)
+                content = tinycss2.parse_blocks_contents(rule.content)
                 declarations = list(preprocess_declarations(base_url, content))
 
                 if declarations:
@@ -1004,7 +1049,7 @@ def preprocess_stylesheet(device_media_type, base_url, stylesheet_rules,
                         continue
                     declarations = list(preprocess_declarations(
                         base_url,
-                        tinycss2.parse_declaration_list(margin_rule.content)))
+                        tinycss2.parse_blocks_contents(margin_rule.content)))
                     if declarations:
                         selector_list = [(
                             specificity, f'@{margin_rule.lower_at_keyword}',
@@ -1014,7 +1059,7 @@ def preprocess_stylesheet(device_media_type, base_url, stylesheet_rules,
 
         elif rule.type == 'at-rule' and rule.lower_at_keyword == 'font-face':
             ignore_imports = True
-            content = tinycss2.parse_declaration_list(rule.content)
+            content = tinycss2.parse_blocks_contents(rule.content)
             rule_descriptors = dict(
                 preprocess_descriptors('font-face', base_url, content))
             for key in ('src', 'font_family'):
@@ -1041,7 +1086,7 @@ def preprocess_stylesheet(device_media_type, base_url, stylesheet_rules,
                 continue
 
             ignore_imports = True
-            content = tinycss2.parse_declaration_list(rule.content)
+            content = tinycss2.parse_blocks_contents(rule.content)
             counter = {
                 'system': None,
                 'negative': None,
@@ -1096,7 +1141,7 @@ def preprocess_stylesheet(device_media_type, base_url, stylesheet_rules,
 def get_all_computed_styles(html, user_stylesheets=None,
                             presentational_hints=False, font_config=None,
                             counter_style=None, page_rules=None,
-                            target_collector=None):
+                            target_collector=None, forms=False):
     """Compute all the computed styles of all elements in ``html`` document.
 
     Do everything from finding author stylesheets to parsing and applying them.
@@ -1112,7 +1157,7 @@ def get_all_computed_styles(html, user_stylesheets=None,
     for style in html._ua_counter_style():
         for key, value in style.items():
             counter_style[key] = value
-    for sheet in (html._ua_stylesheets() or []):
+    for sheet in (html._ua_stylesheets(forms) or []):
         sheets.append((sheet, 'user agent', None))
     if presentational_hints:
         for sheet in (html._ph_stylesheets() or []):
