@@ -54,6 +54,9 @@ def min_content_width(context, box, outer=True):
         return replaced_min_content_width(box, outer)
     elif isinstance(box, boxes.FlexContainerBox):
         return flex_min_content_width(context, box, outer)
+    elif isinstance(box, boxes.GridContainerBox):
+        # TODO: Get real grid size.
+        return block_min_content_width(context, box, outer)
     else:
         raise TypeError(
             f'min-content width for {type(box).__name__} not handled yet')
@@ -81,6 +84,9 @@ def max_content_width(context, box, outer=True):
         return replaced_max_content_width(box, outer)
     elif isinstance(box, boxes.FlexContainerBox):
         return flex_max_content_width(context, box, outer)
+    elif isinstance(box, boxes.GridContainerBox):
+        # TODO: Get real grid size.
+        return block_max_content_width(context, box, outer)
     else:
         raise TypeError(
             f'max-content width for {type(box).__name__} not handled yet')
@@ -135,6 +141,10 @@ def margin_width(box, width, left=True, right=True):
     """Add box paddings, borders and margins to ``width``."""
     percentages = 0
 
+    # See https://drafts.csswg.org/css-tables-3/#cell-intrinsic-offsets
+    # It is a set of computed values for border-left-width, padding-left,
+    # padding-right, and border-right-width (along with zero values for
+    # margin-left and margin-right)
     for value in (
         (['margin_left', 'padding_left'] if left else []) +
         (['margin_right', 'padding_right'] if right else [])
@@ -147,10 +157,24 @@ def margin_width(box, width, left=True, right=True):
                 assert style_value.unit == '%'
                 percentages += style_value.value
 
+    collapse = box.style['border_collapse'] == 'collapse'
     if left:
-        width += box.style['border_left_width']
+        if collapse and hasattr(box, 'border_left_width'):
+            # In collapsed-borders mode: the computed horizontal padding of the
+            # cell and, for border values, the used border-width values of the
+            # cell (half the winning border-width)
+            width += box.border_left_width
+        else:
+            # In separated-borders mode: the computed horizontal padding and
+            # border of the table-cell
+            width += box.style['border_left_width']
     if right:
-        width += box.style['border_right_width']
+        if collapse and hasattr(box, 'border_right_width'):
+            # [...] the used border-width values of the cell
+            width += box.border_right_width
+        else:
+            # [...] the computed border of the table-cell
+            width += box.style['border_right_width']
 
     if percentages < 100:
         return width / (1 - percentages / 100)
@@ -225,19 +249,20 @@ def column_group_content_width(context, box):
 
 def table_cell_min_content_width(context, box, outer):
     """Return the min-content width for a ``TableCellBox``."""
+    # See https://www.w3.org/TR/css-tables-3/#outer-min-content
+    # The outer min-content width of a table-cell is
+    # max(min-width, min-content width) adjusted by
+    # the cell intrinsic offsets.
     children_widths = [
-        min_content_width(context, child) for child in box.children
+        min_content_width(context, child)
+        for child in box.children
         if not child.is_absolutely_positioned()]
-    children_min_width = margin_width(
-        box, max(children_widths) if children_widths else 0)
+    children_min_width = adjust(
+        box,
+        outer,
+        max(children_widths) if children_widths else 0)
 
-    width = box.style['width']
-    if width != 'auto' and width.unit == 'px':
-        cell_min_width = adjust(box, outer, width.value)
-    else:
-        cell_min_width = 0
-
-    return max(children_min_width, cell_min_width)
+    return children_min_width
 
 
 def table_cell_max_content_width(context, box, outer):
@@ -289,10 +314,10 @@ def inline_line_widths(context, box, outer, is_line_start, minimum,
             else:
                 (skip, skip_stack), = skip_stack.items()
                 assert skip_stack is None
-            child_text = child.text[(skip or 0):]
+            child_text = child.text.encode()[(skip or 0):]
             if is_line_start and space_collapse:
-                child_text = child_text.lstrip(' ')
-            if minimum and child_text == ' ':
+                child_text = child_text.lstrip(b' ')
+            if minimum and child_text == b' ':
                 lines = [0, 0]
             else:
                 max_width = 0 if minimum else None
@@ -302,8 +327,8 @@ def inline_line_widths(context, box, outer, is_line_start, minimum,
                     resume_index += new_resume_index
                     _, _, new_resume_index, width, _, _ = (
                         split_first_line(
-                            child_text[resume_index:], child.style, context,
-                            max_width, child.justification_spacing,
+                            child_text[resume_index:].decode(), child.style,
+                            context, max_width, child.justification_spacing,
                             is_line_start=is_line_start, minimum=True))
                     lines.append(width)
                     if first_line:
@@ -412,8 +437,8 @@ def table_and_columns_preferred_widths(context, box, outer=True):
             box, outer=True, width=block_max_content_width(context, table))
         result = ([], [], [], [], total_horizontal_border_spacing, [])
         context.tables[table] = result = {
-            False: (min_width, max_width) + result,
-            True: (outer_min_width, outer_max_width) + result,
+            False: (min_width, max_width, *result),
+            True: (outer_min_width, outer_max_width, *result),
         }
         return result[outer]
 
@@ -597,9 +622,9 @@ def table_and_columns_preferred_widths(context, box, outer=True):
     table_min_content_width = (
         total_horizontal_border_spacing + sum(min_content_widths))
     table_max_content_width = (
-        total_horizontal_border_spacing + max(
-            [sum(max_content_widths), large_percentage_contribution] +
-            small_percentage_contributions))
+        total_horizontal_border_spacing + max([
+            sum(max_content_widths), large_percentage_contribution,
+            *small_percentage_contributions]))
 
     if table.style['width'] != 'auto' and table.style['width'].unit == 'px':
         # "percentages on the following properties are treated instead as
@@ -625,10 +650,8 @@ def table_and_columns_preferred_widths(context, box, outer=True):
         min_content_widths, max_content_widths, intrinsic_percentages,
         constrainedness, total_horizontal_border_spacing, zipped_grid)
     context.tables[table] = result = {
-        False: (table_min_content_width, table_max_content_width) + result,
-        True: (
-            (table_outer_min_content_width, table_outer_max_content_width) +
-            result),
+        False: (table_min_content_width, table_max_content_width, *result),
+        True: (table_outer_min_content_width, table_outer_max_content_width, *result),
     }
     return result[outer]
 
@@ -744,9 +767,12 @@ def trailing_whitespace_size(context, box):
         stripped_box = box.copy_with_text(stripped_text)
         stripped_box, resume, _ = split_text_box(
             context, stripped_box, None, old_resume)
-        assert stripped_box is not None
-        assert resume is None
-        return old_box.width - stripped_box.width
+        if stripped_box is None:
+            # old_box split just before the trailing spaces
+            return old_box.width
+        else:
+            assert resume is None
+            return old_box.width - stripped_box.width
     else:
         _, _, _, width, _, _ = split_first_line(
             box.text, box.style, context, None, box.justification_spacing)
