@@ -5,7 +5,7 @@ from math import ceil, hypot
 
 from ..matrix import Matrix
 from .bounding_box import is_valid_bounding_box
-from .utils import color, parse_url, size, transform
+from .utils import alpha_value, color, parse_url, size, transform
 
 
 def use(svg, node, font_size):
@@ -83,7 +83,7 @@ def draw_gradient(svg, node, gradient, font_size, opacity, stroke):
         positions.append(max(
             positions[-1] if positions else 0,
             size(child.get('offset'), font_size, 1)))
-        stop_opacity = float(child.get('stop-opacity', 1)) * opacity
+        stop_opacity = alpha_value(child.get('stop-opacity', 1)) * opacity
         stop_color = color(child.get('stop-color', 'black'))
         if stop_opacity < 1:
             stop_color = tuple(
@@ -188,6 +188,14 @@ def draw_gradient(svg, node, gradient, font_size, opacity, stroke):
         bx2, by2 = transform_matrix.invert.transform_point(width, height)
         width, height = bx2 - bx1, by2 - by1
 
+        # Ensure that width and height are positive to please some PDF readers
+        if bx1 > bx2:
+            width = -width
+            bx1, bx2 = bx2, bx1
+        if by1 > by2:
+            height = -height
+            by1, by2 = by2, by1
+
     pattern = svg.stream.add_pattern(
         bx1, by1, width, height, width, height, matrix @ svg.stream.ctm)
     group = pattern.add_group(bx1, by1, width, height)
@@ -249,17 +257,15 @@ def spread_linear_gradient(spread, positions, colors, x1, y1, x2, y2,
 
         # Create cycles used to add colors
         if spread == 'repeat':
-            next_steps = cycle([0] + position_steps)
+            next_steps = cycle((0, *position_steps))
             next_colors = cycle(colors)
-            previous_steps = cycle([0] + position_steps[::-1])
+            previous_steps = cycle((0, *position_steps[::-1]))
             previous_colors = cycle(colors[::-1])
         else:
             assert spread == 'reflect'
-            next_steps = cycle(
-                [0] + position_steps[::-1] + [0] + position_steps)
+            next_steps = cycle((0, *position_steps[::-1], 0, *position_steps))
             next_colors = cycle(colors[::-1] + colors)
-            previous_steps = cycle(
-                [0] + position_steps + [0] + position_steps[::-1])
+            previous_steps = cycle((0, *position_steps, 0, *position_steps[::-1]))
             previous_colors = cycle(colors + colors[::-1])
 
         # Normalize bounding box
@@ -402,8 +408,7 @@ def spread_radial_gradient(spread, positions, colors, fx, fy, fr, cx, cy, r,
                 new_positions = [
                     position - 1 - full_repeat for position
                     in original_positions[-(i - 1):]]
-                positions = (
-                    [ratio - 1 - full_repeat] + new_positions + positions)
+                positions = [ratio - 1 - full_repeat, *new_positions, *positions]
                 break
 
     coords = (fx, fy, fr, cx, cy, r)
@@ -422,18 +427,10 @@ def draw_pattern(svg, node, pattern, font_size, opacity, stroke):
     x, y = bounding_box[0], bounding_box[1]
     matrix = Matrix(e=x, f=y)
     if pattern.get('patternUnits') == 'userSpaceOnUse':
-        width, height = svg.inner_width, svg.inner_height
-    else:
-        width, height = bounding_box[2], bounding_box[3]
-
-    if pattern.get('patternUnits') == 'userSpaceOnUse':
-        x = size(pattern.get('x'), font_size, 1)
-        y = size(pattern.get('y'), font_size, 1)
         pattern_width = size(pattern.get('width', 0), font_size, 1)
         pattern_height = size(pattern.get('height', 0), font_size, 1)
     else:
-        x = size(pattern.get('x'), font_size, 1) * width
-        y = size(pattern.get('y'), font_size, 1) * height
+        width, height = bounding_box[2], bounding_box[3]
         pattern_width = (
             size(pattern.attrib.pop('width', '1'), font_size, 1) * width)
         pattern_height = (
