@@ -1,10 +1,4 @@
-"""
-    weasyprint.utils
-    ----------------
-
-    Various utility functions and classes.
-
-"""
+"""Various utility functions and classes for URL management."""
 
 import codecs
 import contextlib
@@ -14,15 +8,16 @@ import sys
 import traceback
 import zlib
 from gzip import GzipFile
+from pathlib import Path
 from urllib.parse import quote, unquote, urljoin, urlsplit
 from urllib.request import Request, pathname2url, urlopen
 
 from . import __version__
 from .logger import LOGGER
 
-# See http://stackoverflow.com/a/11687993/1162888
+# See https://stackoverflow.com/a/11687993/1162888
 # Both are needed in Python 3 as the re module does not like to mix
-# http://tools.ietf.org/html/rfc3986#section-3.1
+# https://datatracker.ietf.org/doc/html/rfc3986#section-3.1
 UNICODE_SCHEME_RE = re.compile('^([a-zA-Z][a-zA-Z0-9.+-]+):')
 BYTES_SCHEME_RE = re.compile(b'^([a-zA-Z][a-zA-Z0-9.+-]+):')
 
@@ -74,11 +69,13 @@ def iri_to_uri(url):
 def path2url(path):
     """Return file URL of `path`.
 
-    Accepts 'str' or 'bytes', returns 'str'.
+    Accepts 'str', 'bytes' or 'Path', returns 'str'.
 
     """
     # Ensure 'str'
-    if isinstance(path, bytes):
+    if isinstance(path, Path):
+        path = str(path)
+    elif isinstance(path, bytes):
         path = path.decode(FILESYSTEM_ENCODING)
     # If a trailing path.sep is given, keep it
     wants_trailing_slash = path.endswith(os.path.sep) or path.endswith('/')
@@ -154,10 +151,19 @@ def get_link_attribute(element, attr_name, base_url):
     uri = get_url_attribute(element, attr_name, base_url, allow_relative=True)
     if uri:
         if base_url:
-            parsed = urlsplit(uri)
-            # Compare with fragments removed
-            if parsed[:-1] == urlsplit(base_url)[:-1]:
-                return ('url', ('internal', unquote(parsed.fragment)))
+            try:
+                parsed = urlsplit(uri)
+            except ValueError:
+                LOGGER.warning('Malformed URL: %s', uri)
+            else:
+                try:
+                    parsed_base = urlsplit(base_url)
+                except ValueError:
+                    LOGGER.warning('Malformed base URL: %s', base_url)
+                else:
+                    # Compare with fragments removed
+                    if parsed.fragment and parsed[:-1] == parsed_base[:-1]:
+                        return ('url', ('internal', unquote(parsed.fragment)))
         return ('url', ('external', uri))
 
 
@@ -178,9 +184,12 @@ def default_url_fetcher(url, timeout=10, ssl_context=None):
     ``url_fetcher`` argument to :class:`HTML` or :class:`CSS`.
     (See :ref:`URL Fetchers`.)
 
-    :param str url: The URL of the resource to fetch.
-    :param int timeout: The number of seconds before HTTP requests are dropped.
-    :param ssl.SSLContext ssl_context: An SSL context used for HTTP requests.
+    :param str url:
+        The URL of the resource to fetch.
+    :param int timeout:
+        The number of seconds before HTTP requests are dropped.
+    :param ssl.SSLContext ssl_context:
+        An SSL context used for HTTP requests.
     :raises: An exception indicating failure, e.g. :obj:`ValueError` on
         syntactically invalid URL.
     :returns: A :obj:`dict` with the following keys:
